@@ -20,7 +20,7 @@ project = 'averell'
 year = '2019-2020'
 author = 'LINHD POSTDATA Project'
 copyright = '{0}, {1}'.format(year, author)
-version = release = '1.0.0'
+version = release = '1.0.1'
 
 pygments_style = 'trac'
 templates_path = ['.']
@@ -31,8 +31,8 @@ extlinks = {
 # on_rtd is whether we are on readthedocs.org
 on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
 
-if not on_rtd:  # only set the theme if we're building docs locally
-    html_theme = 'sphinx_rtd_theme'
+#if not on_rtd:  # only set the theme if we're building docs locally
+html_theme = 'alabaster'
 
 html_use_smartypants = True
 html_last_updated_fmt = '%b %d, %Y'
