@@ -16,14 +16,14 @@ def main():
 
 
 @main.command()
-@click.option('--output', default=Path.cwd() / "corpora",
-              help='Folder to download')
+@click.option('--corpora-folder', default=Path.cwd() / "corpora",
+              help='Local folder where the corpora will be downloaded')
 @click.argument('ids', nargs=-1, type=click.INT)
-def download(ids, output):
+def download(ids, corpora_folder):
     """
     Download the corpus with IDS
     """
-    corpora_features = get_corpora(ids, output)
+    corpora_features = get_corpora(ids, corpora_folder)
     return corpora_features
 
 
@@ -36,6 +36,7 @@ def export(ids, granularity, corpora_folder):
     """
     Parse the corpus with IDs with the GRANULARITY into CORPORA-FOLDER
     """
+    click.echo(f"Using corpora folder: '{corpora_folder}'")
     export_corpora(ids, granularity, corpora_folder)
 
 
