@@ -7,6 +7,8 @@ from averell.cli import export
 from averell.cli import list_command
 from averell.cli import main
 
+from .test_core import _corpora_sources
+
 
 def test_main():
     runner = CliRunner()
@@ -22,33 +24,31 @@ def test_download():
     assert result.exit_code == 0
 
 
-def test_export():
+def test_export_no_ids(caplog):
+    expected = "Using corpora folder: './corpora'\n"
     runner = CliRunner()
     result = runner.invoke(export, [])
 
+    assert result.output == expected
     assert result.exit_code == 0
 
 
-_corpora_sources = [
-        {'name': 'testing',
-         'properties':
-             {
-                 'license': 'CC-BY',
-                 'size': '22M',
-                 'doc_quantity': 4088,
-                 'word_quantity': 381539,
-                 'granularity': ['stanza']
-             }
-         }
-    ]
+@patch('averell.core.CORPORA_SOURCES', _corpora_sources)
+def test_export_not_downloaded(caplog):
+    expected = "Using corpora folder: './corpora'\n"
+    runner = CliRunner()
+    result = runner.invoke(export, ["1", "--granularity", "line"])
+    assert result.output == expected
+    assert result.exit_code == 0
 
 
 @patch('averell.utils.CORPORA_SOURCES', _corpora_sources)
 def test_list():
     expected = "\n".join([
-        '  id  name     size      docs    words  granularity    license',
-        '----  -------  ------  ------  -------  -------------  ---------',
-        '   1  testing  22M       4088   381539  stanza         CC-BY\n',
+        '  id  name      size      docs    words  granularity    license',
+        '----  --------  ------  ------  -------  -------------  ---------',
+        '   1  testing   22M       4088   381539  stanza         CC-BY',
+        '   2  testing2  22M       4088   381539  stanza         CC-BY\n',
         ])
     runner = CliRunner()
     result = runner.invoke(list_command, [])
